@@ -1,3 +1,5 @@
+#!/usr/bin/env -S uv run --script
+
 # Copyright 2016 Alethea Katherine Flowers
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -12,6 +14,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+# /// script
+# dependencies = ["nox>=2025.02.09"]
+# ///
+
 
 from __future__ import annotations
 
@@ -26,16 +32,11 @@ import nox
 
 ON_WINDOWS_CI = "CI" in os.environ and sys.platform.startswith("win32")
 
-nox.needs_version = ">=2024.4.15"
+nox.needs_version = ">=2025.02.09"
 nox.options.default_venv_backend = "uv|virtualenv"
 
 PYPROJECT = nox.project.load_toml("pyproject.toml")
-
-ALL_PYTHONS = [
-    c.split()[-1]
-    for c in PYPROJECT["project"]["classifiers"]
-    if c.startswith("Programming Language :: Python :: 3.")
-]
+ALL_PYTHONS = nox.project.python_versions(PYPROJECT)
 
 
 @nox.session(python=ALL_PYTHONS)
@@ -189,7 +190,7 @@ def _check_python_version(session: nox.Session) -> None:
 @nox.session(
     python=[
         *ALL_PYTHONS,
-        "pypy-3.10",
+        "pypy-3.11",
     ],
     default=False,
 )
@@ -205,9 +206,14 @@ def github_actions_default_tests(session: nox.Session) -> None:
         "pypy3.8",
         "pypy3.9",
         "pypy3.10",
+        "pypy3.11",
     ],
     default=False,
 )
 def github_actions_all_tests(session: nox.Session) -> None:
     """Check all versions installed by the nox GHA Action"""
     _check_python_version(session)
+
+
+if __name__ == "__main__":
+    nox.main()
