@@ -16,6 +16,7 @@ from __future__ import annotations
 
 import contextlib
 import os
+import re
 import shutil
 import subprocess
 import sys
@@ -27,6 +28,7 @@ from unittest import mock
 import pytest
 
 import nox
+import nox._cli
 import nox._options
 import nox.registry
 import nox.sessions
@@ -44,14 +46,17 @@ VERSION = metadata.version("nox")
 os.environ.pop("NOXSESSION", None)
 
 
-def test_main_no_args(monkeypatch: pytest.MonkeyPatch) -> None:
+@pytest.mark.parametrize(
+    "main", [nox.main, nox._cli.nox_main], ids=["main", "nox_main"]
+)
+def test_main_no_args(monkeypatch: pytest.MonkeyPatch, main: Any) -> None:
     monkeypatch.setattr(sys, "argv", [sys.executable])
     with mock.patch("nox.workflow.execute") as execute:
         execute.return_value = 0
 
         # Call the function.
         with mock.patch.object(sys, "exit") as exit:
-            nox.main()
+            main()
             exit.assert_called_once_with(0)
         assert execute.called
 
@@ -627,6 +632,15 @@ def test_main_requries_modern_param(
     assert returncode == 0
 
 
+def test_main_duplicate_session(
+    run_nox: Callable[..., tuple[Any, Any, Any]],
+) -> None:
+    noxfile = os.path.join(RESOURCES, "noxfile_duplicate_sessions.py")
+    msg = "The session 'foo' has already been registered"
+    with pytest.warns(FutureWarning, match=re.escape(msg)):
+        run_nox(f"--noxfile={noxfile}")
+
+
 def test_main_noxfile_options(
     monkeypatch: pytest.MonkeyPatch, generate_noxfile_options: Callable[..., str]
 ) -> None:
@@ -1098,6 +1112,26 @@ def test_noxfile_no_script_mode(monkeypatch: pytest.MonkeyPatch) -> None:
     assert "No module named 'cowsay'" in job.stderr
 
 
+def test_noxfile_script_mode_exec(monkeypatch: pytest.MonkeyPatch) -> None:
+    monkeypatch.delenv("NOX_SCRIPT_MODE", raising=False)
+    job = subprocess.run(
+        [
+            sys.executable,
+            Path(RESOURCES) / "noxfile_script_mode_exec.py",
+            "-s",
+            "exec_example",
+        ],
+        check=False,
+        capture_output=True,
+        text=True,
+        encoding="utf-8",
+    )
+    print(job.stdout)
+    print(job.stderr)
+    assert job.returncode == 0
+    assert "another_world" in job.stdout
+
+
 def test_noxfile_script_mode_url_req() -> None:
     job = subprocess.run(
         [
